==> phplist-2.10.5p0.tgz: lists/admin/lan/pt-br/admin.php <==
<?php

$lan = array(
  'listofadministrators' => 'Lista de Administradores',
'Add a new Administrator' => 'Adicionar um novo Administrador',
  'No Access' => 'Sem Acesso',
  'Changes saved' => 'Altera&ccedil;&otilde;es salvas',
  'Error adding new admin' => 'Erro ao adicionar novo admin',
  'strAccessExplain' => '<hr/>
<p>Defina as permiss&otilde;es de visualiza&ccedil;&atilde;o das p&aacute;ginas do sistema:</p>
<ul>
<li>Todas: admin tem acesso &agrave;s p&aacute;ginas sem nenhuma restri&ccedil;&atilde;o</li>
<li>Visualizar: admin pode ver o conte&uacute;do das p&aacute;ginas, mas sem poder modific&aacute;-las. Atualmente s&oacute; funciona para p&aacute;ginas de "usu&aacute;rio", "usu&aacute;rios" e "membros".
<li>Nenhuma: admin n&atilde;o pode visualizar esta p&aacute;gina</li>
<li>Administrativa: admin pode visualizar esta p&aacute;gina, mas somente o conte&uacute;do das listas que eles administram</li>
</ul>
',
'Edit Administrator' => 'Editar Administrator',
'Admin Details' => 'Detalhes do Admin',
'ID' => 'ID',
'Login Name' => 'Nome de Acesso',
'Normalised loginname' => 'Nome de Acesso Normalizado',
'Email' => 'Email',
'Time Created' => 'Criado',
'Time modified' => 'Modificado',
'Modified by' => 'Modificado por',
'Last time password was changed' => '&Uacute;ltima vez em que a senha foi modificada',
'Is this user Super Admin?' => 'Este usu&aacute;rio &eacute; um Super Admin?',
'Is this account disabled?' => 'Esta conta est&aacute; desativada?',
'Save Changes' => 'Salvar Altera&ccedil&otildees',
'Current set of permissions made default' => 'Conjunto atual de permiss&otilde;es padr&atilde;o',
'Done' => 'Conclu&iacute;do',
'OK' => 'OK',
'Deleting' => 'Apagando',
'Login Name (max 25 chars)' => 'Nome de Acesso (max de 25 caracts)',
'Access Details' => 'Detalhes de Acesso',
'Access Privileges' => 'Privil&eacute;gios de Acesso',
'Type' => 'Tipo',
'Page' => 'P&aacute;gina',
'Set these permissions as default' => 'Definir essas permiss&otilde;es como padr&atilde;o',
'Reset to Default' => 'Restaurar Padr&atilde;o',
'none' => 'nenhum',
'all' => 'todos',
'view' => 'vizualizar',
'owner' => 'administrador',

);

?>

==> phplist-2.10.17p2.tgz: lists/admin/lan/pt-br/admin.php <==
<?php

$lan = array(
  'listofadministrators' => 'Lista de Administradores',
'Add a new Administrator' => 'Adicionar um novo Administrador',
  'No Access' => 'Sem Acesso',
  'Changes saved' => 'Altera&ccedil;&otilde;es salvas',
  'Error adding new admin' => 'Erro ao adicionar novo administrador',
  'strAccessExplain' => '<hr/>
<p class="information">Defina as permiss&otilde;es de visualiza&ccedil;&atilde;o das p&aacute;ginas do sistema:</p>
<ul>
<li>Todas: admin tem acesso &agrave;s p&aacute;ginas sem nenhuma restri&ccedil;&atilde;o</li>
<li>Visualizar: admin pode ver o conte&uacute;do das p&aacute;ginas, mas sem poder modific&aacute;-las. Atualmente s&oacute; funciona para p&aacute;ginas de "usu&aacute;rio", "usu&aacute;rios" e "membros"</li>
<li>Nenhuma: admin n&atilde;o pode visualizar esta p&aacute;gina</li>
<li>Administrativa: admin pode visualizar esta p&aacute;gina, mas somente o conte&uacute;do das listas que eles administram</li>
</ul>
',
'Edit Administrator' => 'Editar Administrator',
'Admin Details' => 'Detalhes do Admin',
'ID' => 'ID',
'Login Name' => 'Nome de Acesso',
'Normalised loginname' => 'Nome de Acesso Normalizado',
'Email' => 'Email',
'Time Created' => 'Criado',
'Time modified' => 'Modificado',
'Modified by' => 'Modificado por',
'Last time password was changed' => '&Uacute;ltima vez em que a senha foi modificada',
'Is this user Super Admin?' => 'Este usu&aacute;rio &eacute; um Super Admin?',
'Is this account disabled?' => 'Esta conta est&aacute; desativada?',
'Save Changes' => 'Salvar Altera&ccedil&otilde;es',
'Current set of permissions made default' => 'Conjunto atual de permiss&otilde;es padr&atilde;o',
'Done' => 'Conclu&iacute;do',
'OK' => 'OK',
'Deleting' => 'Apagando',
'Login Name (max 25 chars)' => 'Nome de Acesso (max de 25 caracts)',
'Access Details' => 'Detalhes de Acesso',
'Access Privileges' => 'Privil&eacute;gios de Acesso',
'Type' => 'Tipo',
'Page' => 'P&aacute;gina',
'Set these permissions as default' => 'Definir essas permiss&otilde;es como padr&atilde;o',
'Reset to Default' => 'Restaurar Padr&atilde;o',
'none' => 'nenhum',
'all' => 'todos',
'view' => 'vizualizar',
'owner' => 'administrador',

);

?>
